# https://mcr.microsoft.com/v2/windows/servercore/tags/list
# As Microsoft will periodically update its API, please take note of the last digits in the build number of the host OS.
# If the host and image build numbers are different, some applications may fail to load, reporting an "EntryPointNotFound" error.
# Another possible error message is "The Windows Installer Service could not be accessed."
# The build number of the host OS may also change as a result of an update by system administrators.
# You can find out the build number of the host OS either in System Information or by running Dump-WindowsVersion from common.ps1
FROM mcr.microsoft.com/windows/servercore:10.0.17763.737

# Each command in this file is a separate layer. 
# Since this is an incremental build, when you modify a command, all the other unchanged commands will be retrieved from cache.
# You may find it convenient to split your commands when testing your image, but be sure to combine them afterwards in order to minimize the number of layers.

WORKDIR "C:/FRS14"
COPY ["./sources/FRS14 x64/", "."]
COPY ["./utils/common.ps1", "./common.ps1"]
COPY ["./utils/ServiceMonitor.exe", "./ServiceMonitor.exe"]

# Now all RUN commands will be executed with this prefix.
# Use a backslash to escape double quotes in RUN commands: \". Only " will be passed to PowerShell.
SHELL ["powershell", "-ExecutionPolicy", "ByPass", "-Command", "$ErrorActionPreference = 'Stop'; . 'C:\\FRS14\\common.ps1';"]

# If double quotes are passed to msiexec incorrectly, this will cause the modal window to freeze.
# In the host OS, you can see how the process was launched inside the cointainer by running the following command in PowerShell as an administrator:
# (Get-WmiObject -Class Win32_Process -Filter 'Name="msiexec.exe"' -Property CommandLine).CommandLine

# LocalDB can't be installed without the redistributables (order is important)
RUN Dump-WindowsVersion; Install-FineReaderServer -Redist -Platform x86; Install-FineReaderServer -Redist -Platform x64; Install-FineReaderServer -LocalDB -Platform x64

# If WEBAPI_SITE_NAME and WEBAPI_SITE_PORT are not specified, FeatureSupportWebService will not be installed.
RUN Install-FineReaderServer -Features 'FeatureCoreFiles,FeatureServerManager,FeatureSupportSharePoint,FeatureComApi,FeatureSupportComPlus,FeatureSupportWebService' -AdditionalArguments @('WEBAPI_SITE_NAME=\"FineReader Server 14\"', 'WEBAPI_SITE_PORT=8080') -Platform x64
RUN Edit-Service -Name 'ABBYY.Server.FineReaderServer.14.0' -Stop -DisableAutoStart
RUN Dump-InstalledPackages; Dump-InstalledABBYYServices

# If you do not want to store the installation package in your image, combine all commands into one, add a delete command at the end, and inside RUN
# replace the command that copies FRS14 x64 with one that downloads the installation package.
# This will keep the installation process within a single layer, and there will be no installation package from the file system at the beginning or at the end of the command.

# Copying these files at the end, to be able to change them without rebuilding an entire image:

# If you want to activate the product with a serial number instead of an online token, 
# comment this line and modify the file all.run.ps1 according to the instructions in that file.
COPY ["./utils/token.ABBYY.Token", "./token.ABBYY.Token"]

COPY ["./utils/entrypoint.ps1", "./entrypoint.ps1"]
ENTRYPOINT ./entrypoint.ps1
